import React, { useState, useEffect } from 'react';
import {FormComponent} from '@formbird/types';
import { convertToCustomElement } from '../utils/CustomElementWrapper';
import { XGrid } from '@material-ui/x-grid';
import { ChangedDocumentService, SearchService } from '@formbird/services';

const ReXGridComponent = ({
  document,
  fieldValue,
  template,
  fieldName,
  formParameters,
  key,
  responsiveLayouts,
  message,
  componentDefinition
}) => {

  const [value, setValue] = useState();
  const [columns] = useState([]);
  const [rows, setRows] = useState([]);
  const [ids, setIds] = useState([]);
  const [loading, setLoading] = useState(false);
  const [rowsPerPageOptions, setRowsPerPageOptions] = useState([5, 10, 15]);

  useEffect(() => {
    if (fieldValue) {
      setValue(fieldValue);
    } else if (componentDefinition.defaultValue) {
      setValue(componentDefinition.defaultValue);
    }
    if (!loading) {
      if ( !(typeof componentDefinition.gridColumns === 'undefined' || componentDefinition.gridColumns === null)) {
        for (let i = 0; i < componentDefinition.gridColumns.length; i++) {
          const col = componentDefinition.gridColumns[i];
          let width = 150;
          if (col.width) { width = col.width; }
          const column = {
            field: col.field,
            headerName: col.displayName,
            flex: 1
          };
          columns.push(column);
        }
      }
      const anyWindow: any = window;
      const searchService: SearchService = (anyWindow.FormbirdServiceInjector).get('SearchService');
      const options = {
        // filter: '{"query":{"bool":{"filter":[{"bool":{"must":[{"match":{"systemHeader.templateId":"fdb2e330-39e6-11e7-a9a1-2faaceda5bd9"}}]}}],"should":[],"must":[]}},"sort":[{"gridTestTextOne":"desc"}],"from":0,"size":10}',
        filter: componentDefinition.filter,
        includeDeleted: true,
        searchOfflineOnly: false,
      };
      setLoading(true);
      searchService.search(options).then((results) => {
        console.log('results = ', results);
        const data = [];
        if (results.data && results.data.hits && results.data.hits.hits) {
          results.data.hits.hits.forEach((item) => {
            const source = item._source;
            if (ids.indexOf(source.documentId) < 0) {
              source.id = source.documentId;
              data.push(source);
              setIds(source.documentId);
            }
          });
        }
        setRows(data);
      }, (err) => {
        setLoading(false);
        console.error('error fetching data', err);
      });
    }
  }, []);

  return (
    <div style={{ height: '800px', width: '100%' }}>
    
    <XGrid
      rows={rows}
      columns={columns}
      loading={rows.length === 0}
      pageSize={componentDefinition.rowsPerPage}
      rowsPerPageOptions={[5, 10, 20]}
      pagination
      // onChange={(e: any) => {
      //   const newValue = e.target.value;
      //   const anyWindow: any = window;
      //   const changedDocumentService: ChangedDocumentService = (anyWindow.FormbirdServiceInjector).get('ChangedDocumentService');

      //   changedDocumentService.valueChanged({
      //     document,
      //     fieldName,
      //     fieldValue,
      //     formParameters,
      //     template,
      //     componentDefinition,
      //     key
      //   }, newValue);

      //   // setValue(newValue);
      // }}
      // {...componentProps}
    />
    </div>
  );
};

// register the component as a custom element so it can be shown in formbird
convertToCustomElement('re-x-grid', ReXGridComponent);

export default ReXGridComponent;
